function histogram=extractRedChromaticityHistogram(img, n, upperBound)
%extractColorHistogram Extracts the color histogram.
%   extractColorHistogram(img) extracts a color histogram with 10 bins per
%   channel.
%
%   extractColorHistogram(img, n) extracts a red chromaticity histogram with n 
%   bins.
%
%   extractColorHistogram(img, n, upperBound) extracts a red chromaticity 
%   histogram with n bins and upperBound as the threshold for clipped  pixels.
%
    if (nargin<3)
        upperBound=255;
        if (nargin<2)
            n=20;
        end
    end
    
    histogram=zeros(n, 1);
    
    [rows, cols, ~]=size(img);
    
    img=double(img);
    count=0;
    for row=1:rows
        for col=1:cols
            
            p=img(row, col, :);
            
            if (sum(p)~=0 && sum(p==upperBound)==0)
                count=count+1;
                
                p=p/sum(p);
                
                idx=floor(p(1)*n)+1;
                if (idx>n)
                    idx=n;
                elseif (idx<1)
					idx=1;
                end
                
                histogram(idx)=histogram(idx)+1;
                
            end
            
        end
    end
    
    histogram=histogram/count;
    
end
